@@ -3,6 +3,10 @@ from django.core import exceptions
 from django.utils.importlib import import_module
 from django.db.models import get_model
 from django.core.cache import cache
+from django.db.models.loading import get_model as django_get_model
+
+def get_model(path):
+    return django_get_model(*path.split('.'))
 
 def load_class(path):
     module_path, class_name = path.rsplit('.', 1)
@@ -32,7 +36,7 @@ def serialize_queryset(queryset):
 def get_categories(*args, **kwargs):
     categories = cache.get('plugshop_categories')
     if categories is None:
-        categories = load_class(settings.CATEGORY_MODEL).objects.all()
+        categories = get_model(settings.CATEGORY_MODEL).objects.all()
         cache.set('plugshop_categories', categories)
     return categories
 
